@@ -340,36 +340,43 @@ AudioControllerThread::playLoop()
             break;
         }
 
-        // Check http -> transcode step of pipe
-        if ( m_transcode->needsData() )
+        if ( m_proxyOutput && m_proxyOutput->isActive() )
         {
-            if ( m_input->hasData() )
-            {
-                QByteArray data;
+            QByteArray data;
+            if ( m_proxyOutput->needsData() && m_input->bufferSize() >= 16384 )
                 m_input->data( data, kCompressedPacketSize );
 
-                m_proxyOutput->processData( data );
-                bool fine = m_transcode->processData( data );
-
-                if ( !fine )
+            m_proxyOutput->processData( data );
+        }
+        else
+        {
+            // Check http -> transcode step of pipe
+            if ( m_transcode->needsData() )
+            {
+                if ( m_input->hasData() )
                 {
-                    LOGL( 2, "MP3 decoding failed, stopping." );
-                    setState( State_Stopping );
-                    break;
+                    QByteArray data;
+                    m_input->data( data, kCompressedPacketSize );
+
+                    bool fine = m_transcode->processData( data );
+                    if ( !fine )
+                    {
+                        LOGL( 2, "MP3 decoding failed, stopping." );
+                        setState( State_Stopping );
+                        break;
+                    }
                 }
             }
-        }
 
-        // Check transcode -> output step of pipe
-        if ( m_output->needsData() )
-        {
-            if ( m_transcode->hasData() )
+            // Check transcode -> output step of pipe
+            if ( m_output->needsData() )
             {
-                QByteArray data;
-                m_transcode->data( data, kUncompressedPacketSize );
-
-                if ( !m_proxyOutput || !m_proxyOutput->isActive() )
+                if ( m_transcode->hasData() )
+                {
+                    QByteArray data;
+                    m_transcode->data( data, kUncompressedPacketSize );
                     m_output->processData( data );
+                }
             }
         }
 
