@@ -59,7 +59,7 @@ DiagnosticsDialog::DiagnosticsDialog( QWidget *parent )
     ui.setupUi( this );
 
     #ifdef HIDE_RADIO
-        ui.tabWidget->removeTab( 1 );
+    ui.radioGroupBox->setVisible( false );
     #endif
     
     #ifdef Q_WS_X11
@@ -98,7 +98,7 @@ DiagnosticsDialog::DiagnosticsDialog( QWidget *parent )
 
     connect( ui.closeButton, SIGNAL( clicked()), SLOT( close() ) );
     connect( qApp, SIGNAL( event( int, QVariant ) ), SLOT( onAppEvent( int, QVariant ) ) );
-    connect( &The::scrobbler(), SIGNAL( status( int, QVariant ) ), SLOT( onScrobblerEvent() ) );
+    connect( &The::scrobbler(), SIGNAL( status( int, QVariant ) ), SLOT( onScrobblerEvent( int ) ) );
     connect( ui.viewLogButton,  SIGNAL( clicked() ), &The::container(), SLOT( onAltShiftL() ) );
     connect( ui.refreshButton, SIGNAL( clicked() ), SLOT( onRefresh() ) );
     connect( ui.copyToClipboardButton, SIGNAL( clicked() ), SLOT( onCopyToClipboard() ) );
@@ -120,6 +120,10 @@ DiagnosticsDialog::DiagnosticsDialog( QWidget *parent )
     m_logTimer = new QTimer( this );
     connect( m_logTimer, SIGNAL( timeout() ),
              this,       SLOT( onLogPoll() ) );
+             
+             
+     ui.reconnect->parentWidget()->layout()->setAlignment( ui.reconnect, Qt::AlignRight );
+     connect( ui.reconnect, SIGNAL(clicked()), SLOT(reconnect()) );
 
 }
 
@@ -218,17 +222,20 @@ DiagnosticsDialog::onAppEvent( int event, const QVariant& /* data */ )
 
 
 void
-DiagnosticsDialog::onScrobblerEvent()
+DiagnosticsDialog::onScrobblerEvent( int status )
 {
     QString const username = The::settings().currentUser().username();
-
+    
     QString submissionStatus = tr( "OK" );
-    if ( The::scrobbler().lastError( username ) != Scrobbler::NoError )
+    if ( The::scrobbler().lastError( username ) != Scrobbler::NoError && The::scrobbler().lastError( username ) != Scrobbler::ErrorNotInitialized)
     {
         submissionStatus = tr( "Error: " ) + Scrobbler::errorDescription( The::scrobbler().lastError( username ) );
     }
-    else
+    else { 
+        if (status == Scrobbler::Connecting)
+            submissionStatus = tr( "Connecting to Last.fm..." );
         ui.lastConnectionStatusLabel->setText( QDateTime::currentDateTime().toString( "d/M/yyyy h:mm" ) );
+    }
 
     ui.submissionServerStatusLabel->setText( submissionStatus );
     populateCacheList( The::settings().currentUser().username() );
@@ -283,7 +290,7 @@ DiagnosticsDialog::onRefresh()
     QString version = The::settings().version();
 
     // Not strictly necessary. Will refresh itself via signal, too.
-    onScrobblerEvent();
+    onScrobblerEvent( Scrobbler::Handshaken );
 
 //     ui.submissionServerStatusLabel->setText( tr( "Checking.." ) );
     ui.radioServerStatusLabel->setText( tr( "Checking.." ) );
@@ -436,3 +443,10 @@ DiagnosticsDialog::onScrobbleIpodClicked()
 
     QProcess::startDetached( The::settings().path() + TWIDDLY_EXECUTABLE_NAME, args );
 }
+
+
+void
+DiagnosticsDialog::reconnect()
+{
+    The::app().setUser( The::currentUsername() );
+}
