@@ -49,6 +49,9 @@ private:
     class QTimer* m_logTimer;
     std::ifstream m_logFile;
 
+public slots:
+    void reconnect();
+
 private slots:
     void close();
 
@@ -58,7 +61,7 @@ private slots:
 
     void radioHandshakeReturn( class Request* );
     void onAppEvent( int event, const QVariant& );
-    void onScrobblerEvent();
+    void onScrobblerEvent( int );
 
     void onRefresh();
     void onCopyToClipboard();
