@@ -81,7 +81,7 @@ MetaDataWidget::MetaDataWidget( QWidget* parent )
     m_tuning_in_timer = new QTimer( this );
     m_tuning_in_timer->setInterval( 6000 );
     m_tuning_in_timer->setSingleShot( true );
-    connect( m_tuning_in_timer, SIGNAL(timeout()), SLOT(onDelayedTuningIn()) );
+    connect( m_tuning_in_timer, SIGNAL( timeout() ), SLOT( onDelayedTuningIn() ) );
 
     #ifndef STATIONARY_WATERMARK
     // Watermark
@@ -97,7 +97,7 @@ MetaDataWidget::MetaDataWidget( QWidget* parent )
     // Set default font on everything as it doesn't work on the Mac otherwise
     QFont defFont = scrollwidget->font();
 
-    qDebug() << "Detected default:" << defFont.toString();
+    qDebug() << "Detected default font:" << defFont.toString();
 
     defFont.setPixelSize( k_standardFontSize );
     ui.buyTrackLabel->setFont( defFont );
@@ -237,41 +237,41 @@ MetaDataWidget::MetaDataWidget( QWidget* parent )
     applyMarginAndSpacing();
 
 //////
-    connect( ui.writeWikiButton, SIGNAL(clicked()), ui.wikiLink, SLOT(openURL()) );
+    connect( ui.writeWikiButton, SIGNAL( clicked() ), ui.wikiLink, SLOT( openURL() ) );
 
-    connect( ui.tagButton, SIGNAL(clicked()),        SIGNAL(tagButtonClicked()) );
-    connect( ui.tagLink,   SIGNAL(leftClickedURL()), SIGNAL(tagButtonClicked()) );
+    connect( ui.tagButton, SIGNAL( clicked() ),        SIGNAL( tagButtonClicked() ) );
+    connect( ui.tagLink,   SIGNAL( leftClickedURL() ), SIGNAL( tagButtonClicked() ) );
 
-    connect( ui.trackLabel,         SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.artistLabel,        SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.albumLabel,         SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.aboutLabel,         SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.tagsLabel,          SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.similarLabel,       SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.topFansLabel,       SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.artistPic,          SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.albumPic,           SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.buyTrackIcon,       SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.buyAlbumIcon,       SIGNAL(urlHovered( const QString& )), SIGNAL(urlHovered( const QString&)) );
+    connect( ui.trackLabel,         SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.artistLabel,        SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.albumLabel,         SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.aboutLabel,         SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.tagsLabel,          SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.similarLabel,       SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.topFansLabel,       SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.artistPic,          SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.albumPic,           SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.buyTrackIcon,       SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.buyAlbumIcon,       SIGNAL( urlHovered( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
 
-    connect( ui.recordLabelLabel,   SIGNAL(enteredURL( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.buyTrackLabel,      SIGNAL(enteredURL( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.buyAlbumLabel,      SIGNAL(enteredURL( const QString& )), SIGNAL(urlHovered( const QString&)) );
-    connect( ui.wikiLink,           SIGNAL(enteredURL( const QString& )), SIGNAL(urlHovered( const QString&)) );
+    connect( ui.recordLabelLabel,   SIGNAL( enteredURL( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.buyTrackLabel,      SIGNAL( enteredURL( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.buyAlbumLabel,      SIGNAL( enteredURL( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
+    connect( ui.wikiLink,           SIGNAL( enteredURL( QUrl ) ), SIGNAL( urlHovered( QUrl ) ) );
 
-    connect( ui.recordLabelLabel,   SIGNAL(leftURL()), SLOT(urlLeft()) );
-    connect( ui.buyTrackLabel,      SIGNAL(leftURL()), SLOT(urlLeft()) );
-    connect( ui.buyAlbumLabel,      SIGNAL(leftURL()), SLOT(urlLeft()) );
-    connect( ui.wikiLink,           SIGNAL(leftURL()), SLOT(urlLeft()) );
+    connect( ui.recordLabelLabel,   SIGNAL( leftURL() ), SLOT( urlLeft() ) );
+    connect( ui.buyTrackLabel,      SIGNAL( leftURL() ), SLOT( urlLeft() ) );
+    connect( ui.buyAlbumLabel,      SIGNAL( leftURL() ), SLOT( urlLeft() ) );
+    connect( ui.wikiLink,           SIGNAL( leftURL() ), SLOT( urlLeft() ) );
 
     clear();
 
-    foreach (QLabel *l, scrollwidget->findChildren<QLabel*>())
+    foreach ( QLabel *l, scrollwidget->findChildren<QLabel*>() )
         l->setTextInteractionFlags( Qt::TextSelectableByMouse );
 
     #ifdef STATIONARY_WATERMARK
     // for stationary watermark painted on viewport()
-    foreach (QWidget* w, m_scrollArea->findChildren<QWidget*>())
+    foreach ( QWidget* w, m_scrollArea->findChildren<QWidget*>() )
         w->setAutoFillBackground( false );
     #endif
 }
@@ -536,7 +536,7 @@ MetaDataWidget::setTrackInfo( const TrackInfo& track )
 
     // EJ: commented out the spinners as they caused a weird hang when skipping a lot
 /*
-    if (!ui.artistPic->movie())
+    if ( !ui.artistPic->movie() )
     {
         QMovie* movie = new QMovie( dataPath( "progress.mng" ) );
         movie->start();
@@ -547,7 +547,7 @@ MetaDataWidget::setTrackInfo( const TrackInfo& track )
     ui.artistPic->show();
 
 /*
-    if (!ui.albumPic->movie())
+    if ( !ui.albumPic->movie() )
     {
         QMovie* movie = new QMovie( dataPath( "progress.mng" ) );
         movie->start();
@@ -912,6 +912,9 @@ MetaDataWidget::updateDragData( const TrackInfo& track )
     data.insert( "album", track.album() );
     data.insert( "track", track.track() );
 
+    ui.artistPic->setItemData( data );
+    ui.albumPic->setItemData( data );
+
     ui.artistLabel->setItemData( 0, data );
     ui.aboutLabel->setItemData( 0, data );
     ui.albumLabel->setItemData( 0, data );
@@ -925,7 +928,7 @@ MetaDataWidget::setArtistMetaData( const MetaData& metadata )
     ui.artistLabel->setText( metadata.artist() );
     ui.aboutLabel->setText( metadata.artist() );
 
-    if ( !metadata.artistPageUrl().isEmpty() ) 
+    if ( !metadata.artistPageUrl().isEmpty() )
     {
         // don't fill in empty URLs as we set preliminary ones in buildHomeBrewedUrls()
         ui.artistLabel->setURL( metadata.artistPageUrl() );
@@ -983,17 +986,14 @@ MetaDataWidget::setArtistMetaData( const MetaData& metadata )
         ui.topFansLabel->setItemFont( i, defFont );
     }
 
-    // No artist pics in Japanese version
-    #ifndef HIDE_RADIO
-        // Download artist picture
-        QUrl url = metadata.artistPicUrl();
-        if ( !url.isEmpty() )
-        {
-            downloadPic( m_coverArtistLoader, url );
-        }
-        else
-            setDefaultArtistPic();
-    #endif
+    // Download artist picture
+    QUrl url = metadata.artistPicUrl();
+    if ( !url.isEmpty() )
+    {
+        downloadPic( m_coverArtistLoader, url );
+    }
+    else
+        setDefaultArtistPic();
 
     updateDragData( metadata );
     adjustArtistLabels();
@@ -1171,7 +1171,7 @@ MetaDataWidget::coverAlbumLoaded( const QByteArray& to )
 bool
 MetaDataWidget::render( const QByteArray& from, ImageButton* to )
 {
-    if ( from.size() > 0 )
+    if ( from.size() > 0 && !from.startsWith( "<?xml" ) )
     {
         QPixmap cover;
         bool success = cover.loadFromData( from );
@@ -1195,7 +1195,7 @@ MetaDataWidget::render( const QByteArray& from, ImageButton* to )
 void
 MetaDataWidget::urlLeft()
 {
-    emit urlHovered( "" );
+    emit urlHovered( QUrl() );
 }
 
 
