@@ -296,19 +296,21 @@ Radio::changeStationRequestReturn( Request* req )
         {
             reHandshake();        
         }
-        else
-        {
-            // Let Container deal with all the error conditions and display appropriate messages
-            emit error( static_cast<RadioError>( request->resultCode() ),
-                        request->errorMessage() );
-
+        else {
+             if (request->resultCode() == ChangeStation_FreeTrialExpired)
+                 emit error( Radio_FreeTrialExpired, request->errorMessage() );
+             else
+                // Let Container deal with all the error conditions and display appropriate messages
+                 emit error( static_cast<RadioError>( request->resultCode() ),
+                             request->errorMessage() );
+                        
             // Reset the GUI state
             setState( State_Stopping );
             setState( State_Stopped );
             
             // The cache for the playlist in audiocontroller is now inaccurate
             m_resumePossible = false;
-        }        
+        }
         
         return;
     }
@@ -387,6 +389,12 @@ void
 Radio::onPlaylistError( RadioError errorCode,
                         const QString& message )
 {
+    if (errorCode == Playlist_FreeTrialExpired)
+    {
+        emit error( Radio_FreeTrialExpired, message );
+        return;
+    }
+    
     if ( errorCode == (int)Playlist_InvalidSession )
     {
         LOGL( 2, "Playlist returned invalid session, scheduling rehandshake..." );
@@ -404,7 +412,7 @@ Radio::onPlaylistError( RadioError errorCode,
     }
     else
     {
-        if ( m_state == State_FetchingPlaylist )
+        if ( m_state == State_FetchingPlaylist)
         {
             emit error( errorCode, message );
     
