@@ -25,11 +25,12 @@
 #include "UnicornCommon.h"
 #include "CachedHttp.h"
 #include "logger.h"
-#include "SideBarRevealPopup.h"
-#include "SideBarModel.h" //FIXME just for enums
-#include "SideBarView.h"
 #include "SideBarDelegate.h"
+#include "SideBarModel.h" //FIXME just for enums
+#include "SideBarRevealPopup.h"
 #include "SideBarToolTipLabel.h"
+#include "SideBarTreeStyle.h"
+#include "SideBarView.h"
 #include "WebService/Request.h"
 #include "Radio.h"
 #include "LastFmSettings.h"
@@ -37,6 +38,7 @@
 #include "ShareDialog.h"
 #include "DragMimeData.h"
 #include "LastMessageBox.h"
+#include "lastfmapplication.h"
 #include "User.h"
 
 #include <QDropEvent>
@@ -59,11 +61,8 @@
 
 SideBarTree::SideBarTree( QWidget* parent ) :
         QTreeView( parent ),
-        m_timer( 0 )
-        
-        #ifndef Q_WS_MAC
-            ,m_treeStyle( 0 )
-        #endif
+        m_timer( 0 ),
+        m_empty_model( true )
 {
     m_model = new SideBarModel;
     m_delegate = new SideBarDelegate;
@@ -98,16 +97,46 @@ SideBarTree::SideBarTree( QWidget* parent ) :
 
     setIconSize( QSize( 24, 24 ) );
     setFrameStyle( QFrame::NoFrame );
-  #else
-    // we can look better for CleanLooks
-    if ( style()->objectName() == "cleanlooks" )
-        setFrameStyle( QFrame::NoFrame );
-    else
-        setFrameShadow( QFrame::Plain );
 
-    m_treeStyle = new TreeStyle();
-    setStyle( m_treeStyle );
-  #endif
+#elif defined WIN32
+    if ( style()->objectName() == "windowsvista" )
+    {
+        setStyle( new TreeStyle<QWindowsVistaStyle> );
+        setStyleSheet( "QTreeView { border: 1px solid palette(dark); border-left: 0; border-top: 0 }" );
+    }
+    else if ( style()->objectName() == "windowsxp" )
+    {
+        setStyle( new TreeStyle<QWindowsXPStyle> );
+    }
+    else
+    {
+        setStyle( new TreeStyle<QWindowsStyle> );
+    }
+    style()->setParent( this );
+
+#elif defined Q_WS_X11
+    if ( style()->objectName() == "cleanlooks" )
+    {
+        // mostly from QCleanLooksStyle.cpp
+        QColor button = palette().button().color();
+        QColor dark;
+        dark.setHsv( button.hue(),
+            qMin( 255, int(button.saturation() * 1.9) ),
+            qMin( 255, int(button.value() * 0.7) ) );
+        dark = dark.light( 108 );
+
+        QString sheet = "QTreeView { border: 1px solid rgb( %1, %2, %3 ); border-top: 0 }";
+        sheet = sheet.arg( dark.red() ).arg( dark.green() ).arg( dark.blue() );
+
+        setStyleSheet( sheet + "QTreeView::branch:adjoins-item { border-color: none }" );
+    }
+    else
+    {
+        setStyle( new TreeStyle<QPlastiqueStyle> );
+        setStyleSheet( "QTreeView { border: 0px }" );
+    }
+
+#endif
 
     header()->hide();
 
@@ -129,17 +158,58 @@ SideBarTree::SideBarTree( QWidget* parent ) :
   #endif
 
     connect( &The::container(), SIGNAL(stackIndexChanged( int )), SLOT(onContainerPageChanged( int )) );
+	connect( qApp, SIGNAL(event( int, QVariant )), SLOT(onAppEvent( int, QVariant )) );
 }
 
 
-SideBarTree::~SideBarTree()
+void
+SideBarTree::onAppEvent( int e, const QVariant& )
 {
-#ifndef Q_WS_MAC
-    delete m_treeStyle;
+    if (e == Event::UserChanged)
+    {
+        if (The::user().settings().sidebarEnabled())
+            makeWebRequests();
+        else {
+            // model will empty itself via UserChanged signal, this should be safe
+            // it will get its signal straight away
+            m_empty_model = true; 
+        }
+    }
+}
+
+
+void
+SideBarTree::showEvent( QShowEvent* )
+{
+    // we only populate the model if the sidebar is visible
+    // rationale: save Last.fm's bandwidth
+    
+    if (m_empty_model)
+        makeWebRequests();
+}
+
+
+void
+SideBarTree::makeWebRequests()
+{
+    m_empty_model = false;
+    
+    (new FriendsRequest)->start();
+    (new NeighboursRequest)->start();
+    (new UserTagsRequest)->start();
+    (new RecentTracksRequest)->start();
+    (new RecentlyLovedTracksRequest)->start();
+
+    UserPicturesRequest* picReq = new UserPicturesRequest();
+    picReq->setNames( QStringList() << The::user().name() );
+    picReq->setImageSize( SIZE_MEDIUM );
+    picReq->start();
+
+#ifndef HIDE_RADIO
+    (new RecentlyBannedTracksRequest)->start();
 #endif
 }
 
-
 void
 SideBarTree::addRecentlyPlayedTrack( Track track )
 {
@@ -166,7 +236,7 @@ SideBarTree::drawRow( QPainter* painter, const QStyleOptionViewItem& option, con
     m_delegate->setSideBarWidth( size().width() );
 
     if (!i.parent().isValid())
-        switch (i.row())
+        switch (m_model->typeAtIndex(i))
         {
             case SideBar::MyProfile:
             {
@@ -270,7 +340,7 @@ void
 SideBarTree::contextMenuEvent( QContextMenuEvent* e )
 {
     // We don't want right click interaction with the MyProfile element
-    if ( SideBarItem( indexAt( e->pos() ) ).type() != SideBar::MyProfile )
+    if ( m_model->typeAtIndex( indexAt( e->pos())) != SideBar::MyProfile )
         contextMenuHandler( indexAt( e->pos() ), ExecQMenu );
 }
 
@@ -326,32 +396,33 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
 {
     //TODO Woah! This became huge. DRY!
     //REFACTOR IMMEDIATELY!
+    // No, refactor when we have the need to edit this code again. ;)
 
     if (!index.isValid())
         return;
 
-    enum ActionType { PlayStation,          PlayGlobalTagRadio,
-                      PlayUserTagRadio,     PlayPersonalRadio,
-                      PlayNeighbourRadio,   PlayLovedRadio,
-                      DeleteFriend,         UnListen,
-                      UnLove,               Love,
-                      UnBan,                Ban,
-                      ClearHistory,         PlayTrack,
-                      TagTrack,             RecommendTrack,
-                      ChangeHistorySize,    RemoveHistoryStation,
-                      SortTagsByPopularity, SortTagsAZ,
-                      SortTagsZA,           SortNeighboursBySimilarity,
-                      SortNeighboursAZ,     SortNeighboursZA,
-                      GoToTrackPage,        GoToTagPage,
-                      GoToUserPage,         GoToFriendsPage,
-                      GoToNeighboursPage,   GoToTagsPage,
-                      AddToPlaylist,
+    enum ActionType { PlayStation,                  PlayGlobalTagRadio,
+                      PlayUserTagRadio,             PlayPersonalRadio,
+                      PlayNeighbourRadio,           PlayLovedRadio,
+                      DeleteFriend,                 UnLove,
+                      Love,                         UnBan,
+                      Ban,                          ClearHistory,
+                      PlayTrack,                    TagTrack,
+                      RecommendTrack,               ChangeHistorySize,
+                      RemoveHistoryStation,         SortTagsByPopularity,
+                      SortTagsAZ,                   SortTagsZA,
+                      SortNeighboursBySimilarity,   SortNeighboursAZ,
+                      SortNeighboursZA,             GoToTrackPage,
+                      GoToTagPage,                  GoToUserPage,
+                      GoToFriendsPage,              GoToNeighboursPage,
+                      GoToTagsPage,                 AddToPlaylist,
                       NoAction };
 
     QString const localizedHost = UnicornUtils::localizedHostName( The::settings().appLanguage() );
     QString text = index.data().toString().replace( '&', "&&" );
     QString const PLAY_THIS_STATION = tr("&Play This Station");
-    SideBarItem i( index );
+    SideBar::Type itemType = m_model->typeAtIndex( index );
+
     QMenu menu( this );
     menu.setSeparatorsCollapsible( true );
     QMap<int, QAction*> map;
@@ -364,13 +435,15 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
     QString const ellipsis;
     #endif
 
-    switch (i.type())
+    #define ICON_OF( index ) index.data( Qt::DecorationRole ).value<QIcon>()
+
+    switch (itemType)
     {
         case SideBar::MyProfile:
             QDesktopServices::openUrl( "http://" + localizedHost + "/user/" + QUrl::toPercentEncoding( The::settings().currentUsername() ) );
             break;
         case SideBar::HistoryStation:
-            map[PlayStation] = menu.addAction( i.icon(), PLAY_THIS_STATION );
+            map[PlayStation] = menu.addAction( ICON_OF( index ), PLAY_THIS_STATION );
             menu.setDefaultAction( map[PlayStation] );
             menu.addSeparator();
             map[RemoveHistoryStation] = menu.addAction( tr("&Remove From History") );
@@ -380,13 +453,14 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
         case SideBar::PersonalRadio:
         case SideBar::LovedTracksRadio:
         case SideBar::NeighbourhoodRadio:
-            map[PlayStation] = menu.addAction( i.icon(), PLAY_THIS_STATION );
+        case SideBar::MyMixRadio:
+            map[PlayStation] = menu.addAction( ICON_OF( index ), PLAY_THIS_STATION );
             menu.setDefaultAction( map[PlayStation] );
             break;
 
         case SideBar::MyTags:
         {
-            map[GoToTagsPage] = menu.addAction( i.icon(), tr("Go To My Tags Page") );
+            map[GoToTagsPage] = menu.addAction( ICON_OF( index ), tr("Go To My Tags Page") );
             menu.addSeparator();
             map[SortTagsByPopularity] = menu.addAction( tr("Sort By Popularity") );
             map[SortTagsByPopularity]->setCheckable( true );
@@ -407,8 +481,11 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
         case SideBar::MyTagsChild:
         {
             text = text.remove( text.lastIndexOf( " (" ), text.length() );
-            map[PlayStation] = menu.addAction( i.icon(), tr("Play This Tag Station") );
-            map[PlayUserTagRadio] = menu.addAction( i.icon(), tr("Play Only Music You Tagged \"%1\"").arg( text ) );
+            map[PlayStation] = menu.addAction( ICON_OF( index ), tr("Play This Tag Station") );
+            if( !The::user().settings().userTagsRadioHidden()) {
+                map[PlayUserTagRadio] = menu.addAction( ICON_OF( index ), tr("Play Only Music You Tagged \"%1\"").arg( text ) );
+            }
+
             menu.addSeparator();
             map[GoToTagPage] = menu.addAction( tr("Go To Tag Page") );
             menu.addSeparator();
@@ -426,7 +503,7 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
 
             sortActions->actions().at( The::settings().currentUser().sideBarTagsSortOrder() )->setChecked( true );
 
-            if ( The::user().isSubscriber() )
+            if ( The::user().isSubscriber() && !The::user().settings().userTagsRadioHidden())
                 menu.setDefaultAction( map[PlayUserTagRadio] );
             else
                 menu.setDefaultAction( map[PlayStation] );
@@ -467,12 +544,12 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
             map[GoToUserPage] = menu.addAction( tr( "Go To %1's Profile" ).arg( text ) );
 
 
-            if (i.type() == SideBar::FriendsChild)
+            if (itemType == SideBar::FriendsChild)
             {
                 menu.addSeparator();
                 map[DeleteFriend] = menu.addAction( tr( "End Friendship" ) + ellipsis );
             }
-            else if (i.type() == SideBar::NeighboursChild)
+            else if (itemType == SideBar::NeighboursChild)
             {
                 menu.addSeparator();
                 map[SortNeighboursBySimilarity] = menu.addAction( tr( "Sort By Similarity" ) );
@@ -507,8 +584,6 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
             map[TagTrack] = menu.addAction( QIcon( MooseUtils::dataPath( "buttons/tag.png" ) ), tr( "Tag..." ) );
             menu.addSeparator();
             map[GoToTrackPage] = menu.addAction( tr( "Go To Track Page" ) );
-            menu.addSeparator();
-            map[UnListen] = menu.addAction( tr( "Remove From Profile" ) + ellipsis );
 
             menu.setDefaultAction( map[PlayTrack] );
             break;
@@ -569,7 +644,7 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
   #endif
 
     QAction *a = 0;
-    if (the_action_to_do == ExecQMenu)
+    if ( the_action_to_do == ExecQMenu && menu.actions().count() )
         a = menu.exec( QCursor::pos() );
     else
         a = menu.defaultAction();
@@ -680,23 +755,23 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
 
         case GoToTrackPage:
             QDesktopServices::openUrl( "http://" + localizedHost + "/music/" +
-                                       UnicornUtils::urlEncodeItem( i.track().artist() ) + "/_/" +
-                                       UnicornUtils::urlEncodeItem( i.track().title() ) + "/" );
+                                       UnicornUtils::urlEncodeItem( m_model->trackAtIndex(index).artist() ) + "/_/" +
+                                       UnicornUtils::urlEncodeItem( m_model->trackAtIndex(index).title() ) + "/" );
             break;
 
         case PlayTrack:
-            The::radio().play( i.track() );
+            The::radio().play( m_model->trackAtIndex( index ) );
             break;
 
         case RecommendTrack:
         {
-            The::shareDialog().setSong( i.track() );
+            The::shareDialog().setSong( m_model->trackAtIndex( index ) );
             The::shareDialog().exec();
         }
         break;
 
         case TagTrack:
-            TagDialog( i.track(), this ).exec();
+            TagDialog( m_model->trackAtIndex( index ), this ).exec();
             break;
 
         #define barg( text ) \
@@ -711,33 +786,28 @@ SideBarTree::contextMenuHandler( const QModelIndex& index, ContextMenuActionType
             break;
 
         case Love:
-            if (ConfirmDialog::love( i.track(), this ))
-                (new LoveRequest( i.track() ))->start();
+            if (ConfirmDialog::love( m_model->trackAtIndex( index ), this ))
+                (new LoveRequest( m_model->trackAtIndex( index ) ))->start();
             break;
 
         case UnLove:
             if (confirm( tr("Do you really want to remove %1 from your Loved Tracks?").barg( index.data().toString() ) ))
-                (new UnLoveRequest( i.track() ))->start();
+                (new UnLoveRequest( m_model->trackAtIndex( index ) ))->start();
             break;
 
         case Ban:
-            if (ConfirmDialog::ban( i.track(), this ))
-                (new BanRequest( i.track() ))->start();
+            if (ConfirmDialog::ban( m_model->trackAtIndex( index ), this ))
+                (new BanRequest( m_model->trackAtIndex( index ) ))->start();
             break;
 
         case UnBan:
             if (confirm( tr( "Do you really want to un-ban %1?" ).arg( index.data().toString() ) ))
-                (new UnBanRequest( i.track() ))->start();
-            break;
-
-        case UnListen:
-            if (confirm( tr( "Do you really want to remove %1 from your profile?" ).barg( index.data().toString() ) ))
-                (new UnListenRequest( i.track() ))->start();
+                (new UnBanRequest( m_model->trackAtIndex( index ) ))->start();
             break;
 
         case AddToPlaylist:
-            if (ConfirmDialog::playlist( i.track(), this ))
-                (new AddToMyPlaylistRequest( i.track() ))->start();
+            if (ConfirmDialog::playlist( m_model->trackAtIndex( index ), this ))
+                (new AddToMyPlaylistRequest( m_model->trackAtIndex( index ) ))->start();
             break;
 
         #undef confirm
@@ -781,7 +851,7 @@ SideBarTree::dragDropHandler( QDropEvent* e )
 {
     QModelIndex i = indexAt( e->pos() );
     if (!i.isValid())
-        return; //TODO throw exception!
+        return; //TODO throw exception! Why?
 
     QString message;
 
@@ -841,14 +911,14 @@ SideBarTree::dragDropHandler( QDropEvent* e )
  */
 
 bool
-SideBarTree::dragDropHandlerPrivate( const QModelIndex& i, QDropEvent* event, QString &status )
+SideBarTree::dragDropHandlerPrivate( const QModelIndex& index, QDropEvent* event, QString &status )
 {
     // we handle drag and drop in the same place to ensure that we don't ie
     // reject the drag, when actually we can do a drop, splitting the code would
     // encourage that kind of bug. Shame this turned into a mahusive function
     // as a result :( --mxcl
 
-    setCurrentIndex( i );
+    setCurrentIndex( index );
 
     bool const is_drop = dynamic_cast<QDragMoveEvent*>(event) == 0;
     if (is_drop)
@@ -857,7 +927,6 @@ SideBarTree::dragDropHandlerPrivate( const QModelIndex& i, QDropEvent* event, QS
         m_timer->start();
 
     DragMimeData const *mimedata = static_cast<const DragMimeData*>(event->mimeData());
-    SideBarItem droptarget( i );
 
 //////
     switch (mimedata->itemType())
@@ -865,13 +934,13 @@ SideBarTree::dragDropHandlerPrivate( const QModelIndex& i, QDropEvent* event, QS
         case UnicornEnums::ItemArtist:
         case UnicornEnums::ItemAlbum:
         case UnicornEnums::ItemTrack:
-            switch (droptarget.type())
+            switch (m_model->typeAtIndex( index ))
             {
                 case SideBar::FriendsChild:
                 case SideBar::NeighboursChild:
                 {
                     TrackInfo const track = mimedata->track();
-                    QString const username = i.data().toString();
+                    QString const username = index.data().toString();
 
                     status = tr("Shares %1 with %2").barg( track.toString() ).barg( username );
                     if (is_drop && ConfirmDialog::share( track, username, this ))
@@ -886,7 +955,7 @@ SideBarTree::dragDropHandlerPrivate( const QModelIndex& i, QDropEvent* event, QS
                 case SideBar::MyTagsChild:
                 {
                     TrackInfo const track = mimedata->track();
-                    QString const tag = i.data().toString().remove( QRegExp(" \\(\\d*\\)$") );
+                    QString const tag = index.data().toString().remove( QRegExp(" \\(\\d*\\)$") );
 
                     QString trackData;
 
@@ -928,7 +997,7 @@ SideBarTree::dragDropHandlerPrivate( const QModelIndex& i, QDropEvent* event, QS
     {
         Track track = mimedata->track();
 
-        switch (droptarget.type())
+        switch (m_model->typeAtIndex( index ))
         {
             case SideBar::RecentlyPlayed:
                 status = tr("You can't add tracks to Recently Played");
@@ -954,7 +1023,7 @@ SideBarTree::dragDropHandlerPrivate( const QModelIndex& i, QDropEvent* event, QS
                 status = tr("Shares %1 with yourself").barg( track.toString() );
                 if (is_drop)
                 {
-                    RecommendRequest* r = new RecommendRequest( track, i.data().toString() );
+                    RecommendRequest* r = new RecommendRequest( track, index.data().toString() );
                     r->setLanguage( The::settings().appLanguage() );
                     r->start();
                 }
@@ -967,9 +1036,9 @@ SideBarTree::dragDropHandlerPrivate( const QModelIndex& i, QDropEvent* event, QS
 
     if (mimedata->hasUser())
     {
-        if (droptarget.classification() == SideBarItem::Track)
+        if (m_model->classificationAtIndex( index ) == SideBarItem::Track)
         {
-            Track const track = droptarget.track();
+            Track const track = m_model->trackAtIndex( index );
             QString const username = mimedata->username();
 
             status = tr("Shares %1 with %2").barg( track ).barg( username );
@@ -988,9 +1057,9 @@ SideBarTree::dragDropHandlerPrivate( const QModelIndex& i, QDropEvent* event, QS
 
     if (mimedata->hasTag())
     {
-        if (droptarget.classification() == SideBarItem::Track)
+        if (m_model->classificationAtIndex( index ) == SideBarItem::Track)
         {
-            Track const track = droptarget.track();
+            Track const track = m_model->trackAtIndex( index );
             QString const tag = mimedata->tag();
 
             status = tr("Tag %1 as %2").barg( track ).barg( tag );
@@ -1129,35 +1198,6 @@ SideBarTree::viewportEvent( QEvent* e )
 #endif
 
 
-#ifdef LINUX
-void
-SideBarTree::paintEvent( QPaintEvent* e )
-{
-    QTreeView::paintEvent( e );
-
-    if (frameShape() == QFrame::NoFrame)
-    {
-        QPainter p( viewport() );
-
-        // mostly from QCleanLooksStyle.cpp
-        QColor button = palette().button().color();
-        QColor dark;
-        dark.setHsv( button.hue(),
-                qMin(255, (int)(button.saturation()*1.9)),
-                qMin(255, (int)(button.value()*0.7)));
-        dark = dark.light( 108 );
-
-        //QStyleOptionFrame opt;
-        //opt.init( this );
-        //opt.rect.adjust( 0, -2, 0, 0 ); //skip drawing the top-line
-        //style()->drawPrimitive( QStyle::PE_Frame, &opt, &p, this );
-        p.setPen( dark );
-        p.drawRect( rect().adjusted( 0, -1, -1, -1 ) );
-    }
-}
-#endif
-
-
 #ifdef HIDE_RADIO
 void
 SideBarTree::reset()
@@ -1170,6 +1210,7 @@ SideBarTree::reset()
     setRowHidden( StartAStation, blank, true );
     setRowHidden( MyRecommendations, blank, true );
     setRowHidden( PersonalRadio, blank, true );
+    setRowhidden( MyMixRadio, blank, true );
     setRowHidden( LovedTracksRadio, blank, true );
     setRowHidden( NeighbourhoodRadio, blank, true );
     setRowHidden( Spacer2, blank, true );
