@@ -240,6 +240,9 @@ CComponentInfo::Clear()
     mInstalled = eUnknown;
     mVersionNewer = eUnknown;
     mSize = 0;
+    mMajorUpgrade = false;
+    mDescription = "";
+    mImage = QUrl();
 }
 
 /******************************************************************************
