@@ -23,6 +23,7 @@
 #define COMPONENTINFO_H
 
 #include <QString>
+#include <QUrl>
 
 #include <vector>
 
@@ -36,7 +37,7 @@ public:
     /*********************************************************************/ /**
         Ctor/Dtor
     **************************************************************************/
-    CComponentInfo() : mInstalled(eUnknown), mVersionNewer(eUnknown) { }
+    CComponentInfo() : mInstalled(eUnknown), mVersionNewer(eUnknown), mMajorUpgrade( false ) { }
     virtual ~CComponentInfo() { }
 
     /*********************************************************************/ /**
@@ -53,6 +54,12 @@ public:
     QString GetVersion() { return msVersion; }
     virtual QString GetInstallPath();
     QString GetInstallArgs() { return msInstallArgs; }
+    QString GetDescription() const { return mDescription; }
+    QUrl GetImage() const { return mImage; }
+
+    void SetMajorUpgrade( bool major ) { mMajorUpgrade = major; }
+    void SetImage( const QUrl& url ) { mImage = url; }
+    void SetDescription( const QString& desc ) { mDescription = desc; }
 
     void SetName(
         const QString& sName) { msName = sName; }
@@ -70,6 +77,7 @@ public:
     /*********************************************************************/ /**
         Isers
     **************************************************************************/
+    bool IsMajorUpgrade() const { return mMajorUpgrade; }
     virtual bool IsInstalled();
     virtual bool IsVersionNewer();
     virtual bool IsRunning();
@@ -135,7 +143,10 @@ private:
     QString msDownloadURL;
     QString msVersion;
     QString msInstallArgs;
+    QString mDescription;
+    QUrl mImage;
 
+    bool mMajorUpgrade;
     unsigned int mSize;
 
 };
