@@ -25,8 +25,11 @@
 #include "WebService.h"
 #include "LastMessageBox.h"
 #include "container.h"
-#include "Bootstrapper/iTunesBootstrapper.h"
-#include "Bootstrapper/PluginBootstrapper.h"
+
+#ifndef Q_WS_X11
+    #include "Bootstrapper/iTunesBootstrapper.h"
+    #include "Bootstrapper/PluginBootstrapper.h"
+#endif
 
 
 using namespace std;
@@ -39,7 +42,6 @@ bool ConfigWizard::s_wizardRunning = false;
 ******************************************************************************/
 ConfigWizard::ConfigWizard( QWidget* parent, Mode mode,  QString uid )
         : BaseWizard( parent ),
-          m_page8( NULL ),
           m_mode( mode ),
           m_bootstrapAllowed( false ),
           m_didBootstrap( false ),
@@ -134,11 +136,6 @@ ConfigWizard::ConfigWizard( QWidget* parent, Mode mode,  QString uid )
     m_doneInfoPlugin =
         tr("The plugin(s) you selected have now been installed.");
 
-    m_doneInfoMediaDeviceYes = 
-        tr("Your iPod has now been connected to your Last.fm account");
-    m_doneInfoMediaDeviceNo = 
-        tr("Your iPod has not been connected to your Last.fm account");
-
     #ifdef Q_WS_MAC
         setTitle(tr("Set up Last.fm"));
     #else 
@@ -150,9 +147,9 @@ ConfigWizard::ConfigWizard( QWidget* parent, Mode mode,  QString uid )
         case Login:
             m_pageOffset = 0;
           #ifdef WIN32
-            setNumPages(10);
+            setNumPages(11);
           #elif defined Q_WS_MAC
-            setNumPages(6);
+            setNumPages(7);
           #elif defined Q_WS_X11
             setNumPages(3);
           #endif
@@ -164,8 +161,8 @@ ConfigWizard::ConfigWizard( QWidget* parent, Mode mode,  QString uid )
             #endif
             
             setTitle(tr("Set up Last.fm for your iPod"));
-            m_pageOffset = 7;
-            setNumPages( 3 );
+            m_pageOffset = 9;
+            setNumPages( 2 );
             break;            
 
         case Plugin:
@@ -242,6 +239,7 @@ QWidget* ConfigWizard::createPage( int index )
             connect( &m_infoGetter, SIGNAL( progressMade( int, int ) ),
                      m_page4,       SLOT( setProgress( int, int ) ) );
             connect( &m_infoGetter, SIGNAL( statusChange( QString ) ),
+            
                      m_page4,       SIGNAL( detailedInfoChanged( QString ) ) );
             m_page4->setInfo( m_detectInfo );
 
@@ -288,14 +286,14 @@ QWidget* ConfigWizard::createPage( int index )
 				list[0].SetPlayerName( "iTunes" );
 				list[0].SetBootstrapType( "Client" );
 				
-			#else //Q_WS_MAC
+			#else //not Q_WS_MAC
 			
 	            vector<CPluginInfo>& list = The::container().getPluginList();
             
 	            if( list.empty() )
 	                list = mAvailPlugins;
 	
-			#endif //!Q_WS_MAC
+			#endif
 
             m_page7->populate( list );
 
@@ -303,20 +301,10 @@ QWidget* ConfigWizard::createPage( int index )
         }
         break;
 
-        case 7:
-        {
-            const QString& info = m_mediaDeviceQuestion;
-            m_page8 = new WizardMediaDeviceAskPage(this, info);
-            adjustSize();
-
-            return m_page8;
-        }
-        break;
-
         case 8:
         {
+            #ifndef Q_WS_X11
             // Create a bootstrapper progress page
-
             const QString& info = m_bootstrapInfo;
 
             m_page9 = new WizardBootstrapPage(this, info);
@@ -339,13 +327,41 @@ QWidget* ConfigWizard::createPage( int index )
                          this,              SLOT  (onBootstrapDone( int ) ) );
             }
 
-
             return m_page9;
+            #endif
         }
         break;
 
-
         case 9:
+        {
+            switch (m_mode)
+            {
+              #ifndef Q_WS_X11
+                case MediaDevice:
+                case Login:
+                case Plugin:
+                    if ( twiddlyBootstrapRequired() )
+                        break;
+              #endif
+
+                // FALL THROUGH
+
+                default:
+                    // don't do the twiddly bootstrap
+                    // returning 0 forces the basewizard to do nextButtonClicked()
+                    m_pageOffset++;
+                    setNumPages( numPages() - 1 );
+                    return 0;
+            }
+
+            m_pageTwiddly = new WizardTwiddlyBootstrapPage( this );
+            connect( m_pageTwiddly, SIGNAL(done()), SLOT(onTwiddlyBootstrapDone()) );
+            enableNext( false );
+            return m_pageTwiddly;
+        }
+        break;
+
+        case 10:
         {
             QString info;
 
@@ -361,12 +377,10 @@ QWidget* ConfigWizard::createPage( int index )
             }
             else if ( m_mode == MediaDevice )
             {
-                if ( m_page8 && m_page8->uiWidget.yesButton->isChecked() )
-                    info = m_doneInfoMediaDeviceYes;
-                else
-                    info = m_doneInfoMediaDeviceNo;
+                info = tr( "Last.fm is now ready for iPod scrobbling. Scrobbles should show up on your profile within 20 minutes of syncing your iPod with iTunes." );
             }
 
+            #ifndef Q_WS_X11
             if ( m_didBootstrap )
             {
                 info += "<p>"; // we may have already got a text from above
@@ -394,8 +408,19 @@ QWidget* ConfigWizard::createPage( int index )
                             info += m_doneInfoPluginBootstrapExtra;
                         }
                         break;
+
+                    case AbstractBootstrapper::Bootstrap_Denied:
+                        info += tr( "It was not possible to import your listening history. "
+                                    "Could it be that you've already imported it?" );
+                        break;
+
+                    default:
+                        Q_ASSERT( !"unhandled" );
+                        break;
+
                 }
             }
+            #endif
 
             m_page10 = new WizardInfoPage( this, info );
             enableBack(false);
@@ -413,7 +438,7 @@ QWidget* ConfigWizard::createPage( int index )
 ******************************************************************************/
 QString
 ConfigWizard::headerForPage(
-    int index)
+    int index )
 {
     index += m_pageOffset;
 
@@ -428,7 +453,8 @@ ConfigWizard::headerForPage(
         case 6: return m_bootstrapHeader;     break;
         case 7: return m_mediaDeviceHeader;   break;
         case 8: return m_bootstrapHeader;     break;
-        case 9: return m_doneHeader;          break;
+        case 9: return tr("Preparing for iPod Scrobbling");
+        case 10: return m_doneHeader;          break;
     }
 
     return "";
@@ -462,7 +488,7 @@ ConfigWizard::nextButtonClicked()
         case 1:
         {
             // Leaving login page, verify login details
-            QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+            QApplication::setOverrideCursor( Qt::WaitCursor );
             m_page2->verify();
 
             //disable next / forward buttons during verification
@@ -513,7 +539,6 @@ ConfigWizard::nextButtonClicked()
 
             if ( m_page7 && m_page7->selectedPlugin() != NULL )
             {
-
                 CPluginInfo* bootstrapPlugin = m_page7->selectedPlugin();
 
                 if( !bootstrapPlugin )
@@ -522,6 +547,7 @@ ConfigWizard::nextButtonClicked()
                     return;
                 }
 
+                #ifndef Q_WS_X11
                 switch( bootstrapPlugin->GetBootstrapType() )
                 {
                 case CPluginInfo::BOOTSTRAP_CLIENT:
@@ -545,7 +571,6 @@ ConfigWizard::nextButtonClicked()
                     Q_ASSERT( !"not possible" );
                 }
 
-
                 setNumPages( numPages() - 1 );
                 m_pageOffset++;
 
@@ -558,11 +583,12 @@ ConfigWizard::nextButtonClicked()
                 nextButtonClicked();
 
                 m_bootstrapper->bootStrap();
-               
+
                 if( !dynamic_cast<AbstractFileBootstrapper*>( m_bootstrapper ) )
                 {
                     onBootstrapDone( AbstractBootstrapper::Bootstrap_Ok );
                 }
+                #endif
 
                 return;
             }
@@ -575,45 +601,21 @@ ConfigWizard::nextButtonClicked()
         break;
 
         case 7:
-        {
-            // This is where the iPod connect wizard starts
-            if ( m_page8 )
-            {
-                // If m_page8 exists, we have been asked the iPod question
-                if ( m_page8->uiWidget.yesButton->isChecked() )
-                {
-                    The::settings().addMediaDevice( m_uid,
-                                                    m_page8->uiWidget.userComboBox->itemText( m_page8->uiWidget.userComboBox->currentIndex() ) );
-
-/*                  if ( !The::settings().bootstrap() )
-                    {
-                        BaseWizard::nextButtonClicked();
-                        return;
-                    }
-                    else*/
-                    {
-                        setNumPages( numPages() - 1 );
-                        m_pageOffset++;
-                    }
-                }
-                else
-                {
-                    The::settings().addMediaDevice( m_uid, "<disabled>" );
-                    setNumPages( numPages() - 1 );
-                    m_pageOffset++;
-                }
-            }
-        }
         break;
 
         case 8:
         {
-            // Leaving the bootstrap progress screen
-                       
+            // next clicked on bootstrap progress page
+        }
+        break;
+        
+        case 9:
+        {
+            // next clicked on Twiddly Bootstrap page
         }
         break;
 
-        case 9:
+        case 10:
         {
             // Done page
         }
@@ -847,6 +849,7 @@ ConfigWizard::reject()
 void
 ConfigWizard::onBootstrapDone( int status )
 {
+    #ifndef Q_WS_X11
     bool pluginBootstrap = dynamic_cast<PluginBootstrapper*>( m_bootstrapper );
     if( pluginBootstrap )
     {
@@ -882,12 +885,16 @@ ConfigWizard::onBootstrapDone( int status )
 
         BaseWizard::nextButtonClicked();
     }   // !pluginBootstrap
+    #endif
 }
 
 
 int
 ConfigWizard::exec()
 {
+    if (m_mode == MediaDevice && !twiddlyBootstrapRequired())
+        return QDialog::Accepted;
+        
     s_wizardRunning = true;
     activateWindow();
 
@@ -901,3 +908,32 @@ ConfigWizard::exec()
 
     return r;
 }
+
+
+void
+ConfigWizard::onTwiddlyBootstrapDone()
+{
+    BaseWizard::nextButtonClicked();
+    enableNext( true );
+}
+
+
+bool
+ConfigWizard::twiddlyBootstrapRequired()
+{
+  #ifdef Q_OS_WIN
+    // Check plugin version is new enough to bootstrap
+    if ( The::settings().pluginVersion( "itw" ).split( '.' ).value( 0 ).toInt() < 3 )
+        return false;
+  #endif
+    
+    QProcess p;
+    p.start( TWIDDLY_PATH, QStringList() << "--bootstrap-needed?" );
+    
+    if ( !p.waitForFinished() )
+        // better to let the plugin manage the bootstrap if we can't be sure
+        // it's needed, returning true could lead to misscrobbles
+        return false;
+
+    return p.exitCode();
+}
