@@ -39,6 +39,7 @@
 #include "loginwidget.h"
 #include "mediadevices/ipod/IpodDevice.h"
 #include "MediaDeviceScrobbler.h"
+#include "RestStateMessage.h"
 #include "metadata.h"
 #include "MetaDataWidget.h"
 #include "playerlistener.h"
@@ -54,8 +55,10 @@
 #include "RestStateWidget.h"
 #include "updatewizard.h"
 #include "User.h"
+#include "toolbarvolumeslider.h"
 #include "WebService.h"
 #include "WebService/Request.h"
+#include "StationUrl.h"
 
 #include <QShortcut>
 #include <QLabel>
@@ -740,6 +743,8 @@ Container::onRadioError( RadioError error, const QString& message )
 
     QString msgboxTitle = tr( "Error" );
 
+    removeDMCAWarnings();
+
     switch( error )
     {
         // TODO: do we really want a statusbar message for all of these?
@@ -766,6 +771,21 @@ Container::onRadioError( RadioError error, const QString& message )
         }
         break;
 
+        case Request_Gone:
+        {
+            LastMessageBox::critical( tr( "This station is no longer available" ), message, QMessageBox::Ok, QMessageBox::Ok, QStringList( tr("Dismiss")) );
+
+            if( The::radio().stationUrl().endsWith( "/loved" )) {
+                QTimer::singleShot( 0, ui.sidebar->model(), SLOT( removeLovedTracks()));
+            }
+            
+            if( The::radio().stationUrl().startsWith( "lastfm://usertags/" )) {
+                The::user().settings().setUserTagsRadioHidden( true );
+                The::radio().playStation( The::radio().stationUrl().replace(QRegExp("lastfm://usertags/[^/]*/"), "lastfm://globaltags/"));
+            }
+        }
+        break;
+
         case Handshake_Banned:
         {
             //TODO make a nicer shutdown (or start upgrade process) via a signal to the container
@@ -927,7 +947,11 @@ Container::updateCheckDone( bool updatesAvailable, bool error, QString errorMsg
     // Go ahead and launch update wizard
     LOG( 3, "New updates available. Launching update wizard.\n" );
 
-    UpdateWizard( *m_updater, this ).exec();
+    UpdateWizard* wizard = new UpdateWizard( *m_updater, this );
+    if( wizard->shouldShow()) {
+        wizard->exec();
+        wizard->deleteLater();
+    }
 
 #ifdef WIN32
     // this is really only for beta testers,
@@ -1888,6 +1912,7 @@ Container::onRadioStateChanged( RadioState newState )
     {
         case State_Stopped:
         {
+            removeDMCAWarnings();
             ui.stationTimeBar->clear();
             ui.stationTimeBar->setEnabled( false );
             ui.stationTimeBar->hide();
@@ -1910,6 +1935,23 @@ Container::onRadioStateChanged( RadioState newState )
             statusBar()->showMessage( tr( "Retrieving playlist..." ) );
         }
         break;
+
+        case State_ChangingStation:
+        {
+            if( !The::radio().stationUrl().isDMCACompatible() && //show message when station is non-DMCA compatible
+                ui.stack->findChildren<RestStateMessage*>( "DMCA" ).isEmpty() ) //Don't show > 1 message
+            {
+                RestStateMessage* dmcaMsg = new RestStateMessage( ui.stack );
+                dmcaMsg->setObjectName( "DMCA" );
+                dmcaMsg->setFaqVisible( false );
+                dmcaMsg->setMessage( tr( "This station will soon be discontinued due to changes coming to Last.fm radio." ) +  " <a href='http://www.last.fm/stationchanges2010'>" +
+                                 tr( "Find out more" ) + "</a>." );
+                dmcaMsg->show();
+            } else if( The::radio().stationUrl().isDMCACompatible()) {
+                removeDMCAWarnings();
+            }
+
+        }
     }
 
     /** skip/ban */
@@ -1988,6 +2030,18 @@ Container::getPluginList()
 }
 
 
+void 
+Container::removeDMCAWarnings()
+{
+    QList<RestStateMessage*> currentMessages = ui.stack->findChildren<RestStateMessage*>( "DMCA" );
+    foreach( RestStateMessage* dmcaMsg, currentMessages ) {
+        dmcaMsg->hide();
+        dmcaMsg->deleteLater();
+    }
+
+}
+
+
 ///////////////////////////////////////////////////////////////////////////////>
 ScrobbleLabel::ScrobbleLabel()
 {
