@@ -23,7 +23,6 @@
 #include "lastfmapplication.h"
 
 #include "configwizard.h"
-#include "confirmdialog.h"
 #include "container.h"
 #include "LastMessageBox.h"
 #include "libFingerprint/FingerprintCollector.h"
@@ -66,6 +65,8 @@
     #include <Carbon/Carbon.h>
 #endif
 
+static void qMsgHandler( QtMsgType, const char* );
+
 
 LastFmApplication::LastFmApplication( int& argc, char** argv )
         : QApplication( argc, argv ),
@@ -122,7 +123,6 @@ LastFmApplication::LastFmApplication( int& argc, char** argv )
 
     connect( this, SIGNAL( event( int, QVariant ) ), SLOT( onAppEvent( int, QVariant ) ) );
 
-    initLogger();
     initTranslator();
     registerMetaTypes();
 
@@ -269,28 +269,6 @@ LastFmApplication::init()
     }
   #endif
 
-  #ifdef QT_NO_DEBUG
-  #ifndef LINUX
-    {
-        qDebug() << "Preferred application for lastfm url-scheme:" << UnicornUtils::preferredAppForUrlScheme( QUrl( "lastfm://" ) );
-        qDebug() << "Our app:" << MooseUtils::bundleDirPath();
-
-        bool b = ( MooseUtils::bundleDirPath() == UnicornUtils::preferredAppForUrlScheme( QUrl( "lastfm://" ) ) );
-        if ( !b )
-        {
-            ConfirmDialog d( m_container );
-            d.setText( tr( "The Last.fm Client is currently not the default player for Last.fm streams.\nDo you want to change that? *CHANEGCOPY*" ) );
-            d.setOperationString( "urlhandler" );
-
-            if ( d.exec() )
-            {
-                qDebug() << "Setting client as the default lastfm url-scheme handler worked:" << UnicornUtils::setPreferredAppForUrlScheme( QUrl( "lastfm://" ), MooseUtils::bundleDirPath() );
-            }
-        }
-    }
-  #endif
-  #endif
-
     // Do we have a current user?
     QString currentUser = The::settings().currentUsername();
     bool doLogin = false;
@@ -383,20 +361,6 @@ LastFmApplication::~LastFmApplication()
 }
 
 
-void
-LastFmApplication::initLogger()
-{
-    QString filename = "Last.fm.log";
-
-    Logger& logger = Logger::GetLogger();
-    logger.Init( MooseUtils::logPath( filename ), false );
-    logger.SetLevel( Logger::Debug );
-
-    LOGL( 3, "App version: " << The::settings().version() );
-    LOGL( 3, "OS version: " << UnicornUtils::getOSVersion() );
-}
-
-
 void
 LastFmApplication::initTranslator()
 {
