@@ -30,7 +30,7 @@
 
 #include <cmath>
 #include <cassert>
-#include <cstdlib>
+#include <cstring>
 #include <iostream>
 #include <sstream>
 #include <cstdlib> 
