@@ -28,8 +28,7 @@
 #include <QSqlError>
 #include <QVariant>
 
-#define COLLECTION_DB_VERSION 1
-
+static const int k_collectionDbVersion = 1;
 
 // Singleton instance needs to be initialised
 Collection* Collection::s_instance = NULL;
@@ -51,10 +50,11 @@ Collection::~Collection()
 Collection&
 Collection::instance()
 {
+    static QMutex mutex;
+    QMutexLocker locker( &mutex );
+
     if ( !s_instance )
     {
-        static QMutex mutex;
-        QMutexLocker locker( &mutex );
         s_instance = new Collection;
     }
 
@@ -148,9 +148,9 @@ Collection::initDatabase()
     }
     
     int const v = version();
-    if ( v < COLLECTION_DB_VERSION )
+    if ( v < k_collectionDbVersion )
     {
-        qDebug() << "Upgrading Collection::db from" << v << "to" << COLLECTION_DB_VERSION;
+        qDebug() << "Upgrading Collection::db from" << v << "to" << k_collectionDbVersion;
 
         /**********************************************
          * README!!!!!!!                              *
@@ -168,7 +168,7 @@ Collection::initDatabase()
             query( "UPDATE files SET fpId = NULL;" );
 
             query( "CREATE TABLE metadata ("
-                        "key         TEXT,"
+                        "key         TEXT UNIQUE NOT NULL,"
                         "value       TEXT );" );
 
             query( "INSERT INTO metadata (key, value) VALUES ('version', '1');" );
@@ -177,7 +177,7 @@ Collection::initDatabase()
 
         // do last, update DB version number
         query( "UPDATE metadata set key='version', value='"
-                    + QString::number( COLLECTION_DB_VERSION ) + "';" );
+                    + QString::number( k_collectionDbVersion ) + "';" );
     }
 
     return true;
