@@ -170,6 +170,13 @@ StopWatch::run()
 
         QDateTime currentTime = QDateTime::currentDateTime();
         int msSpentSleeping = mLastTime.time().msecsTo( currentTime.time() );
+
+        // HACK: This is for when we pass midnight, QTime only works with days
+        // so the msSpentSleeping will be a huge negative number. Force it
+        // to 1000 and everything will be fine.
+        if ( msSpentSleeping < 0 )
+            msSpentSleeping = 1000;
+
         if ( msSpentSleeping >= 1000 )
         {
             mLastTime = currentTime;
@@ -177,11 +184,9 @@ StopWatch::run()
             mnTotalMs += msSpentSleeping;
             mnTimer = mnTotalMs / (int)1000;
 
-            /*
-            LOGL( 3, "msSpent: " << msSpentSleeping );
-            LOGL( 3, "ms: " << mnTotalMs );
-            LOGL( 3, "s: " << mnTimer );
-            */
+            //LOGL( 3, "msSpent: " << msSpentSleeping );
+            //LOGL( 3, "ms: " << mnTotalMs );
+            //LOGL( 3, "s: " << mnTimer );
 
             // Poll for timeout every second
             if (!mbTimedOut && mnTimer >= mnTimeout)
