@@ -251,55 +251,3 @@ UnicornUtils::iTunesIsOpen()
 {
     return isProcessRunning( "iTunes" );
 }
-
-
-bool
-UnicornUtils::setPreferredAppForUrlScheme( const QUrl& url, const QString& app )
-{
-    QString scheme = url.scheme();
-    CFStringRef urlStr = CFStringCreateWithCharacters( NULL, reinterpret_cast<const UniChar *>( scheme.unicode() ), scheme.length() );
-    CFStringRef bundleStr = CFStringCreateWithCharacters( NULL, reinterpret_cast<const UniChar *>( app.unicode() ), app.length() );
-
-    CFURLRef bundleURL;
-    CFBundleRef bundleRef;
-    bundleURL = CFURLCreateWithFileSystemPath( kCFAllocatorDefault, bundleStr, kCFURLPOSIXPathStyle, true );
-    bundleRef = CFBundleCreate( kCFAllocatorDefault, bundleURL );
-
-    CFStringRef appIdentifier = CFBundleGetIdentifier( bundleRef );
-    OSStatus err = LSSetDefaultHandlerForURLScheme( urlStr, appIdentifier );
-
-    CFRelease( urlStr );
-    CFRelease( bundleStr );
-    CFRelease( bundleURL );
-    CFRelease( bundleRef );
-
-    return ( err == noErr );
-}
-
-
-QString
-UnicornUtils::preferredAppForUrlScheme( const QUrl& url )
-{
-    QString app;
-    QString scheme = url.scheme() + "://";
-
-    CFStringRef urlStr = CFStringCreateWithCharacters( NULL, reinterpret_cast<const UniChar *>( scheme.unicode() ), scheme.length() );
-    CFURLRef urlRef = CFURLCreateWithString( NULL, urlStr, NULL );
-
-    FSRef appRef;
-    OSStatus err = LSGetApplicationForURL( urlRef, kLSRolesAll, &appRef, NULL );
-
-    if ( err == noErr )
-    {
-        unsigned char path[512];
-        err = ::FSRefMakePath( &appRef, path, 512 );
-
-        if ( err == noErr )
-            app = (const char*)path;
-    }
-
-    CFRelease( urlStr );
-    CFRelease( urlRef );
-
-    return QDir::cleanPath( app );
-}
