@@ -76,7 +76,7 @@ public:
     bool succeeded() const { return m_result == Request_Success; }
     bool aborted() const { return m_result == Request_Aborted; }
 
-    QString errorMessage() const;
+    virtual QString errorMessage() const;
 
     /// default is true
     void setAutoDelete( bool b ) { m_auto_delete = b; }
@@ -341,6 +341,7 @@ public:
 
     virtual void start();
     virtual void success( QByteArray data );
+    virtual QString errorMessage() const;
 };
 
 
