@@ -189,6 +189,9 @@ enum WebRequestResultCode
     /// Authentication failed, probably show user settings dialog
     Request_WrongUserNameOrPassword,
 
+    /// Resource no longer exists
+    Request_Gone,
+
     // class Handshake codes
     // ------------------------------------------------------------------------
     Handshake_WrongUserNameOrPassword,
