@@ -775,7 +775,7 @@ DragLabel::leaveEvent( QEvent* /*event*/ )
     m_hoverPoint = QPoint( -1, -1 );
     update();
 
-    emit urlHovered( "" );
+    emit urlHovered( QUrl() );
 }
 
 void
@@ -847,7 +847,7 @@ DragLabel::mouseMoveEvent( QMouseEvent *event )
     {
         setCursor( QCursor( Qt::ArrowCursor ) );
 
-        emit urlHovered( "" );
+        emit urlHovered( QUrl() );
     }
     else
     {
@@ -859,11 +859,8 @@ DragLabel::mouseMoveEvent( QMouseEvent *event )
         setCursor( QCursor( Qt::PointingHandCursor ) );
 
         // Emit hovered over url
-        QString url = m_items[m_hoverIndex].m_url.toString();
-        if ( !url.isEmpty() )
-        {
-            emit urlHovered( url );
-        }
+        if ( !m_items[m_hoverIndex].m_url.isEmpty() )
+            emit urlHovered( m_items[m_hoverIndex].m_url );
     }
 
     // Early out if left button isn't pressed or we're not over a pill
