@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 - 2007 by                                          *
+ *   Copyright (C) 2005 - 2008 by                                          *
  *      Christian Muehlhaeuser, Last.fm Ltd <chris@last.fm>                *
  *      Erik Jaelevik, Last.fm Ltd <erik@last.fm>                          *
  *      Jono Cole, Last.fm Ltd <jono@last.fm>                              *
@@ -30,6 +30,8 @@
 
 #include <QHeaderView>
 #include <QProcess>
+#include <QPluginLoader>
+#include <QLibrary>
 
 #include "Radio.h"
 #include "LastFmSettings.h"
@@ -47,14 +49,15 @@ static const unsigned char kRussian[] =
     { 0xD0, 0xA0, 0xD1, 0x83, 0xD1, 0x81, 0xD1, 0x81, 0xD0, 0xBA,
       0xD0, 0xB8, 0xD0, 0xB9, 0x0 };
 static const unsigned char kJapanese[] =
-    { 0xE6, 0x97, 0xA5, 0xE6, 0x9C, 0xAC, 0xE8, 0xAA, 0x9E, 0x0 }; 
+    { 0xE6, 0x97, 0xA5, 0xE6, 0x9C, 0xAC, 0xE8, 0xAA, 0x9E, 0x0 };
 
 
 SettingsDialog::SettingsDialog( QWidget *parent )
-        : QDialog( parent ), 
+        : QDialog( parent ),
           m_reconnect( false ),
           m_reAudio( false ),
-          m_populating( false )
+          m_populating( false ),
+          m_closeAfterVerification( false )
 {
     ui.setupUi( this );
 
@@ -91,6 +94,10 @@ SettingsDialog::SettingsDialog( QWidget *parent )
     ui.pageStack->addWidget( mediadeviceWidget );
 #endif
 
+#ifdef NBREAKPAD
+    ui_connection.crashReportCheck->hide();
+#endif
+
     // Add icons to user icon dropdown
     QPixmap pixmap( MooseUtils::dataPath( "icons/user_red.png" ) );
     ui_account.colourCombo->setItemIcon( 0, pixmap );
@@ -107,7 +114,7 @@ SettingsDialog::SettingsDialog( QWidget *parent )
     ui_account.languageCombo->addItem( tr( "System Language" ), "" );
     ui_account.languageCombo->addItem( "English",
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::English ) );
-    ui_account.languageCombo->addItem( QString("Fran") + QChar( 0xe7 ) + QString( "ais" ),
+    ui_account.languageCombo->addItem( QString( "Fran" ) + QChar( 0xe7 ) + QString( "ais" ),
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::French ) );
     ui_account.languageCombo->addItem( "Italiano",
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::Italian ) );
@@ -115,18 +122,20 @@ SettingsDialog::SettingsDialog( QWidget *parent )
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::German ) );
     ui_account.languageCombo->addItem( QString( "Espa" ) + QChar( 0xf1 ) + QString( "ol" ),
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::Spanish ) );
-    ui_account.languageCombo->addItem( QString( "Portugu" ) + QChar( 0xea ) + QString( "s" ), 
+    ui_account.languageCombo->addItem( QString( "Portugu" ) + QChar( 0xea ) + QString( "s" ),
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::Portuguese ) );
-    ui_account.languageCombo->addItem( "Polski", 
+    ui_account.languageCombo->addItem( "Polski",
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::Polish ) );
-    ui_account.languageCombo->addItem( "Svenska", 
+    ui_account.languageCombo->addItem( "Svenska",
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::Swedish ) );
-    ui_account.languageCombo->addItem( QString::fromUtf8("Türkçe"),
+    ui_account.languageCombo->addItem( QString::fromUtf8( "Türkçe" ),
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::Turkish ) );
-    ui_account.languageCombo->addItem( QString::fromUtf8( (const char*) kRussian ), 
+    ui_account.languageCombo->addItem( QString::fromUtf8( (const char*) kRussian ),
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::Russian ) );
-    ui_account.languageCombo->addItem( QString::fromUtf8( (const char*) kChinese ), 
+    ui_account.languageCombo->addItem( QString::fromUtf8( (const char*) kChinese ),
         UnicornUtils::qtLanguageToLfmLangCode( QLocale::Chinese ) );
+    ui_account.languageCombo->addItem( QString::fromUtf8( "日本語" ), 
+        UnicornUtils::qtLanguageToLfmLangCode( QLocale::Japanese ) );
 
     // Add icons to sidebar
     pixmap.load( MooseUtils::dataPath( "/icons/options_account.png" ) );
@@ -186,10 +195,12 @@ SettingsDialog::SettingsDialog( QWidget *parent )
 
     adjustSize();
 
-    connect( ui.pageList, SIGNAL(currentRowChanged( int )), SLOT(pageSwitched( int )) );
-    connect( ui.okButton, SIGNAL(clicked()), SLOT(onOkClicked()) );
-    connect( ui.applyButton, SIGNAL(clicked()), SLOT(applyPressed()) );
-    connect( ui_connection.clearCacheButton, SIGNAL(clicked()), SLOT(clearCache()) );
+    connect( ui.buttonBox, SIGNAL( accepted() ), SLOT( onOkClicked() ) );
+    connect( ui.buttonBox, SIGNAL( rejected() ), SLOT( reject() ) );
+    connect( ui.buttonBox->button( QDialogButtonBox::Apply ), SIGNAL( clicked() ), SLOT( applyPressed() ) );
+
+    connect( ui.pageList, SIGNAL( currentRowChanged( int ) ), SLOT( pageSwitched( int ) ) );
+    connect( ui_connection.clearCacheButton, SIGNAL( clicked() ), SLOT( clearCache() ) );
 
     connect( m_loginWidget, SIGNAL( verifyResult( bool, bool ) ), SLOT( verifiedAccount( bool, bool ) ) );
     connect( m_loginWidget, SIGNAL( widgetChanged() ), this, SLOT( configChanged() ) );
@@ -214,18 +225,20 @@ SettingsDialog::SettingsDialog( QWidget *parent )
     connect( ui_connection.automaticProxyButton, SIGNAL( toggled( bool ) ), this, SLOT( configChanged() ) );
     connect( ui_connection.manualProxyButton, SIGNAL( toggled( bool ) ), this, SLOT( configChanged() ) );
     connect( ui_connection.downloadMetadataCheck, SIGNAL( toggled( bool ) ), this, SLOT( configChanged() ) );
+#ifndef NBREAKPAD
     connect( ui_connection.crashReportCheck, SIGNAL( toggled( bool ) ), this, SLOT( configChanged() ) );
+#endif
 
     #ifndef Q_WS_X11
-    connect( ui_mediadevices.deviceWidget, SIGNAL( currentItemChanged( QTreeWidgetItem*, QTreeWidgetItem* ) ), this, SLOT( mediaDeviceItemSelected( QTreeWidgetItem*, QTreeWidgetItem* ) ) );
-    connect( ui_mediadevices.removeButton, SIGNAL( clicked() ), this, SLOT( removeMediaDevice() ) );
-    connect( ui_mediadevices.iPodEnabledCheck, SIGNAL( toggled( bool ) ), this, SLOT( configChanged() ) );
+    connect( ui_mediadevices.enableIPodScrobbling, SIGNAL( toggled( bool ) ), SLOT( configChanged() ) );
+    connect( ui_mediadevices.alwaysConfirmIPodScrobbles, SIGNAL( toggled( bool ) ), SLOT( configChanged() ) );
+    connect( ui_mediadevices.giveMoreFeedback, SIGNAL( toggled( bool ) ), SLOT( configChanged() ) );
+    connect( ui_mediadevices.clearUserAssociations, SIGNAL( clicked() ), SLOT( clearUserIPodAssociations() ) );
     #endif
 
     #ifdef Q_WS_MAC
         connect( ui_scrobbling.launchWithMediaPlayerCheck, SIGNAL( toggled( bool ) ), this, SLOT( configChanged() ) );
         connect( ui_account.showInDockCheck, SIGNAL( toggled( bool ) ), this, SLOT( configChanged() ) );
-        ui_mediadevices.iPodEnabledCheck->hide();
     #endif
 }
 
@@ -261,17 +274,59 @@ SettingsDialog::exec( int startPage )
     populateMediaDevices();
     #endif
 
-    foreach ( ExtensionInterface* i, extensions )
+    loadExtensions();
+    foreach ( ExtensionInterface* i, m_extensions )
         i->populateSettings();
     m_populating = false;
 
     pageSwitched( startPage );
-    ui.applyButton->setEnabled( false );
+    ui.buttonBox->button( QDialogButtonBox::Apply )->setEnabled( false );
 
     return QDialog::exec();
 }
 
 
+void
+SettingsDialog::loadExtensions()
+{
+    foreach( QString path, Moose::extensionPaths() )
+    {
+        // NOTE we should test isLoaded() first really, but for some reason
+        // this wasn't working on Windows with Qt 4.3.1
+
+	    QObject* plugin = QPluginLoader( path ).instance();
+	    if ( !plugin )
+	    {
+    		LOGL( 2, "Failed to retrieve instance from loaded plugin: " << path );
+	    	continue;
+	    }
+
+	    ExtensionInterface* iExtension = qobject_cast<ExtensionInterface *>( plugin );
+	    if ( iExtension && iExtension->hasSettingsPane() )
+	    {
+	        LOGL( 3, "Loaded a settings extension from: " << path );
+	        addExtension( iExtension ); //adds page to dialog
+	    }
+    }
+}
+
+
+#ifdef Q_WS_MAC
+static bool appHasDockIcon()
+{
+    QProcess p;
+    p.start( "defaults", QStringList() << "read" << Moose::bundleDirPath() + "/Contents/Info" << "LSUIElement" );
+    p.waitForFinished();
+    
+    if (p.exitCode() == 0)
+        return p.readAllStandardOutput().trimmed() != "1";
+    else
+        // nonzero exit code means no LSUIElement, thus shown
+        return true;
+}
+#endif
+
+
 void
 SettingsDialog::populateAccount()
 {
@@ -280,13 +335,14 @@ SettingsDialog::populateAccount()
     ui_account.colourCombo->setCurrentIndex( user->icon() < ui_account.colourCombo->count() ? user->icon() : 0 );
 
     #ifdef Q_WS_MAC
-        ui_account.showInDockCheck->setChecked( isDockIconVisible() );
-
         ui_account.showInTrayCheck->setText( tr( "Show application icon in menu bar" ) );
+
+        ui_account.showInDockCheck->setChecked( appHasDockIcon() );
     #endif
 
     ui_account.showInTrayCheck->setChecked( The::settings().showTrayIcon() );
 
+
     #ifndef HIDE_RADIO
         QString langCode = The::settings().customAppLanguage();
         for( int i = 0; i < ui_account.languageCombo->count(); ++i )
@@ -330,13 +386,8 @@ SettingsDialog::populateScrobbling()
 
     ui_scrobbling.scrobblePointSlider->setValue( user.scrobblePoint() );
     ui_scrobbling.scrobblePointLabel->setText( QString::number( user.scrobblePoint() ) );
-
-    ui_scrobbling.launchWithMediaPlayerCheck->setChecked( user.launchWithMediaPlayer() );
-
-    ui_scrobbling.fingerprintCheckBox->setCheckState( user.fingerprintingEnabled() ?
-                                                        Qt::Checked : 
-                                                        Qt::Unchecked );
-
+    ui_scrobbling.launchWithMediaPlayerCheck->setChecked( The::settings().launchWithMediaPlayer() );
+    ui_scrobbling.fingerprintCheckBox->setChecked( user.fingerprintingEnabled() );
     ui_scrobbling.dirTree->setExclusions( user.excludedDirs() );
 }
 
@@ -350,7 +401,9 @@ SettingsDialog::populateConnection()
     ui_connection.proxyUsernameEdit->setText( The::settings().getProxyUser() );
     ui_connection.proxyPasswordEdit->setText( The::settings().getProxyPassword() );
     ui_connection.downloadMetadataCheck->setChecked( The::settings().currentUser().isMetaDataEnabled() );
+#ifndef NBREAKPAD
     ui_connection.crashReportCheck->setChecked( The::settings().currentUser().crashReportingEnabled() );
+#endif
     ui_connection.manualProxyButton->setChecked( The::settings().isUseProxy() );
 }
 
@@ -358,28 +411,20 @@ SettingsDialog::populateConnection()
 void
 SettingsDialog::populateMediaDevices()
 {
-    ui_mediadevices.iPodEnabledCheck->setChecked( The::settings().currentUser().isiPodScrobblingEnabled() );
+    ui_mediadevices.enableIPodScrobbling->setChecked( The::settings().isIPodScrobblingEnabled() );
+    ui_mediadevices.alwaysConfirmIPodScrobbles->setChecked( The::currentUser().isAlwaysConfirmIPodScrobbles() );
+    ui_mediadevices.giveMoreFeedback->setChecked( The::currentUser().giveMoreIPodScrobblingFeedback() );
 
-    QList<QTreeWidgetItem *> items;
-    ui_mediadevices.deviceWidget->clear();
+    QList<QTreeWidgetItem*> items;
     foreach( QString device, The::settings().allMediaDevices() )
     {
-        if ( !The::settings().mediaDeviceUser( device ).isEmpty() )
-        {
-            QStringList list;
-            list << device;
-            list << The::settings().mediaDeviceUser( device );
-
-            QTreeWidgetItem* item = new QTreeWidgetItem( (QTreeWidget*)0, list );
-
-            bool const b = The::settings().isManualIpod( device );
-            item->setCheckState( 2, b ? Qt::Checked : Qt::Unchecked );
-
-            items.append( item );
-        }
+        QString username = The::settings().usernameForDeviceId( device );
+        items += new QTreeWidgetItem( QStringList() << device << username );
     }
 
+    ui_mediadevices.deviceWidget->clear();
     ui_mediadevices.deviceWidget->insertTopLevelItems( 0, items );
+    ui_mediadevices.clearUserAssociations->setEnabled( items.count() );
 
     //NOTE manual scrobbling is disabled on Windows and Mac and this option
     // is irrelevent on Linux since manual is the only supported option
@@ -399,24 +444,30 @@ void
 SettingsDialog::applyPressed()
 {
     // Do hardcoded sections
-    if (m_pagesToSave.contains( 0 )) { saveAccount(); }
-    if (m_pagesToSave.contains( 1 )) { saveRadio(); }
-    if (m_pagesToSave.contains( 2 )) { saveScrobbling(); }
-    if (m_pagesToSave.contains( 3 )) { saveConnection(); }
-    if (m_pagesToSave.contains( 4 )) { saveMediaDevices(); }
+    if ( m_pagesToSave.contains( 1 ) ) saveRadio();
+    if ( m_pagesToSave.contains( 2 ) ) saveScrobbling();
+    if ( m_pagesToSave.contains( 3 ) ) saveConnection();
+    if ( m_pagesToSave.contains( 4 ) ) saveMediaDevices();
 
     // Do extensions
-    foreach (int page, m_pagesToSave)
+    foreach ( int page, m_pagesToSave )
     {
         if( page < 5)
             continue;
 
         int idx = page - 5;
-        extensions[idx]->saveSettings();
+        m_extensions[idx]->saveSettings();
         m_pagesToSave.remove( page );
     }
 
-    ui.applyButton->setEnabled( false );
+    // Account has to be the last section we handle here:
+    // It relies on signals being received and in case
+    // the user pressed Ok, this will close and free the
+    // dialog asap.
+    if ( m_pagesToSave.contains( 0 ) )
+        saveAccount();
+
+    ui.buttonBox->button( QDialogButtonBox::Apply )->setEnabled( false );
 }
 
 
@@ -431,6 +482,7 @@ void
 SettingsDialog::verifiedAccount( bool verified, bool /* bootstrap */ )
 {
     if ( verified )
+        // FIXME: why specify false? Better specify true and cause a rehandshake straight away.
         m_loginWidget->save( false );
     else 
         m_loginWidget->resetWidget( The::settings().currentUsername() );
@@ -441,6 +493,22 @@ SettingsDialog::verifiedAccount( bool verified, bool /* bootstrap */ )
 
     The::settings().setShowTrayIcon( ui_account.showInTrayCheck->isChecked() );
 
+#ifdef Q_WS_MAC
+    if (appHasDockIcon() != ui_account.showInDockCheck->isChecked())
+    {
+        QProcess p;
+        p.start( "defaults", QStringList() << "write"
+                                           << Moose::bundleDirPath() + "/Contents/Info"
+                                           << "LSUIElement"
+                                           << (ui_account.showInDockCheck->isChecked() ? "0" : "1") );
+        p.waitForFinished();
+    
+        p.start( "touch", QStringList() << Moose::bundleDirPath() ); //no need to wait
+        
+        LastMessageBox::say( tr("You need to restart the application for the dock icon appearance change to take effect.") );
+    }
+#endif
+
 #ifndef HIDE_RADIO
     // Store language in config
     int langIdx = ui_account.languageCombo->currentIndex();
@@ -460,10 +528,6 @@ SettingsDialog::verifiedAccount( bool verified, bool /* bootstrap */ )
     The::settings().setAppLanguage( langCode );
 #endif
 
-#ifdef Q_WS_MAC
-    toggleDockIcon();
-#endif
-
     if( !verified )
     {
         //verification failed so don't close the dialog after saving.
@@ -476,6 +540,9 @@ SettingsDialog::verifiedAccount( bool verified, bool /* bootstrap */ )
     }
 
     pageSaved( 0 );
+
+    if ( m_closeAfterVerification )
+        accept();
 }
 
 
@@ -509,8 +576,9 @@ SettingsDialog::saveScrobbling()
     LastFmUserSettings& user = The::settings().currentUser();
     user.setScrobblePoint( ui_scrobbling.scrobblePointSlider->value() );
     user.setExcludedDirs( ui_scrobbling.dirTree->getExclusions() );
-    user.setLaunchWithMediaPlayer( ui_scrobbling.launchWithMediaPlayerCheck->isChecked() );
+    The::settings().setLaunchWithMediaPlayer( ui_scrobbling.launchWithMediaPlayerCheck->isChecked() );
     user.setFingerprintingEnabled( ui_scrobbling.fingerprintCheckBox->checkState() == Qt::Checked ? true : false );
+
     pageSaved( 2 );
 }
 
@@ -524,7 +592,9 @@ SettingsDialog::saveConnection()
     The::settings().setProxyPort( ui_connection.proxyPortEdit->text().toInt() );
     The::settings().setUseProxy( ui_connection.manualProxyButton->isChecked() );
     The::settings().currentUser().setMetaDataEnabled( ui_connection.downloadMetadataCheck->isChecked() );
+#ifndef NBREAKPAD
     The::settings().currentUser().setCrashReportingEnabled( ui_connection.crashReportCheck->isChecked() );
+#endif
 
     m_reconnect =  ui_connection.proxyHostEdit->text()              != originalProxyHost     ||
                    ui_connection.proxyUsernameEdit->text()          != originalProxyUsername ||
@@ -543,18 +613,27 @@ SettingsDialog::saveConnection()
 void
 SettingsDialog::saveMediaDevices()
 {
-    if ( ui_mediadevices.iPodEnabledCheck->isChecked() &&
-         !The::settings().currentUser().isiPodScrobblingEnabled() )
+    bool changed = ui_mediadevices.enableIPodScrobbling->isChecked() != The::settings().isIPodScrobblingEnabled();
+    if (changed)
     {
-        MooseUtils::enableHelperApp();
-    }
-    else if ( !ui_mediadevices.iPodEnabledCheck->isChecked() &&
-              The::settings().currentUser().isiPodScrobblingEnabled() )
-    {
-        MooseUtils::disableHelperApp();
+        if (ui_mediadevices.enableIPodScrobbling->isChecked())
+        {
+            LastMessageBox::say( tr("You must restart iTunes before Last.fm can scrobble your iPod" ) );
+        }
+        else
+        {
+        #ifdef Q_OS_MAC
+            // we delete the plugin db when iTunes restarts as we can't delete
+            // it now, on Windows at least it's in use, but it's safe to leave
+            // it, ie, there can be no miss-scrobbles, and we ignore any 
+            // twiddles here in the client from now on
+        #endif
+        }
     }
 
-    The::settings().currentUser().setiPodScrobblingEnabled( ui_mediadevices.iPodEnabledCheck->isChecked() );
+    The::settings().setIPodScrobblingEnabled( ui_mediadevices.enableIPodScrobbling->isChecked() );
+    The::currentUser().setAlwaysConfirmIPodScrobbles( ui_mediadevices.alwaysConfirmIPodScrobbles->isChecked() );
+    The::currentUser().setGiveMoreIPodScrobblingFeedback( ui_mediadevices.giveMoreFeedback->isChecked() );
 
     for (int x = 0; x < ui_mediadevices.deviceWidget->topLevelItemCount(); ++x)
     {
@@ -567,34 +646,16 @@ SettingsDialog::saveMediaDevices()
 }
 
 
-void
-SettingsDialog::mediaDeviceItemSelected( QTreeWidgetItem* /*current*/, QTreeWidgetItem* /*previous*/ )
-{
-    ui_mediadevices.removeButton->setEnabled( ui_mediadevices.deviceWidget->currentItem() != 0 );
-}
-
-
-void
-SettingsDialog::removeMediaDevice()
-{
-    if ( ui_mediadevices.deviceWidget->currentItem() )
-    {
-//         qDebug() << "Removing device:" << ui_mediadevices.deviceWidget->currentItem()->text( 0 );
-        The::settings().removeMediaDevice( ui_mediadevices.deviceWidget->currentItem()->text( 0 ) );
-        delete ui_mediadevices.deviceWidget->currentItem();
-    }
-
-    ui_mediadevices.removeButton->setEnabled( ui_mediadevices.deviceWidget->topLevelItemCount() > 0 );
-}
-
-
 void
 SettingsDialog::onOkClicked()
 {
-    accept();
+    m_closeAfterVerification = true;
 
     if( m_pagesToSave.size() > 0 )
         applyPressed();
+
+    if ( !m_pagesToSave.contains( 0 ) )
+        accept();
 }
 
 
@@ -631,14 +692,14 @@ SettingsDialog::configChanged()
     if( !m_pagesToSave.contains( ui.pageList->currentRow() ) && ui.pageList->currentRow() >= 0 )
           m_pagesToSave.insert( ui.pageList->currentRow() );
 
-    ui.applyButton->setEnabled( true );
+    ui.buttonBox->button( QDialogButtonBox::Apply )->setEnabled( true );
 }
 
 
 void
 SettingsDialog::addExtension( ExtensionInterface* ext )
 {
-    extensions.append( ext );
+    m_extensions.append( ext );
 
     ext->setOwner( this );
 
@@ -694,7 +755,7 @@ SettingsDialog::clearCache()
         QString result;
         if ( success )
         {
-            result = tr( "Cache emptied. %n file(s) deleted.", "", count );
+            result = tr( "Cache emptied. %n files deleted.", "", count );
         }
         else
         {
@@ -715,142 +776,24 @@ SettingsDialog::clearCache()
 }
 
 
-#ifdef Q_WS_MAC
-	void 
-	SettingsDialog::toggleDockIcon()
-	{		
-		if ( ui_account.preferencesGroup->isHidden() )
-			return;
-		
-		// Application itself is in .app/Content/MacOS/, info.plist in .app/Content -> ../info.plist
-		#ifdef QT_NO_DEBUG
-			QString infoPlistFile = "../info.plist";
-		#else
-			// It's only possible to test this function in debug mode on a working final release - located usually in /Applications
-			// This means that you can't hide the icon of the debug version itself in debug mode.
-            // NOTE: There has to be a working release version of the application in the path above! Otherwise this option is invisible...
-			QString infoPlistFile = "/Applications/Last.fm.app/Contents/info.plist";
-		#endif
-		
-		QFile file( infoPlistFile );
-        
-		if ( file.open( QIODevice::ReadOnly ) ) 
-		{
-			// Open plist and read all
-			QTextStream fileStream( &file );
-			fileStream.setCodec( "UTF-8" );
-			
-			QString fileContent = fileStream.readAll();
-			
-			file.close();
-			
-			// Determine if plist includes the LSUIElement key, which sets the icon visibility
-			bool previousDockIconState;
-			
-			if ( fileContent.indexOf( "\t<key>LSUIElement</key>\n\t<string>1</string>\n" ) == -1 )
-				previousDockIconState = true;
-			else
-				previousDockIconState = false;
-			
-			// Check if there are any changes to the saved state in the plist
-			if ( previousDockIconState == ui_account.showInDockCheck->isChecked() )
-				return;
-			
-			LastMessageBox dlg( QMessageBox::Information,
-							 tr( "Restart Needed" ),
-							 tr( "You need to restart the application for the dock icon appearance "
-								 "change to take effect." ),
-							 QMessageBox::Ok, this );
-            dlg.exec();
-			
-			// Open plist file again, this time with writing access
-			if ( file.open( QIODevice::WriteOnly | QIODevice::Truncate ) )
-			{
-				// Check if icon isn't set hidden and the user wants to hide it
-				if ( fileContent.indexOf( "\t<key>LSUIElement</key>\n\t<string>1</string>\n" ) == -1 
-											&& !ui_account.showInDockCheck->isChecked() )
-				{
-					fileContent.replace( "</dict>\n"
-										 "</plist>", 
-										 "\t<key>LSUIElement</key>\n"
-										 "\t<string>1</string>\n"
-										 "</dict>\n"
-										 "</plist>", Qt::CaseInsensitive );
-					fileContent.replace( "\t<key>LSUIElement</key>\n"
-										 "\t<string>0</string>\n", 
-										 "", Qt::CaseInsensitive);
-				}
-				else
-				{
-					fileContent.replace( "\t<key>LSUIElement</key>\n"
-										 "\t<string>0</string>\n", "", Qt::CaseInsensitive );
-					fileContent.replace( "\t<key>LSUIElement</key>\n"
-										 "\t<string>1</string>\n", "", Qt::CaseInsensitive );
-				}
-				
-				fileStream.seek( 0 );
-				fileStream << fileContent;
-				
-				fileStream.flush();
-				file.close();
-				
-				QProcess launcherService;
-				launcherService.start( "/System/Library/Frameworks/ApplicationServices.framework"
-					// See comment above why I'm doing this...
-					#ifdef QT_NO_DEBUG
-						"/Versions/A/Frameworks/LaunchServices.framework/Versions/A/Support/lsregister -v -f " +
-						QCoreApplication::applicationDirPath().remove( "/Contents/MacOS" ) );
-					#else
-					   "/Versions/A/Frameworks/LaunchServices.framework/Versions/A/Support/lsregister -v -f /Applications/LastFM.app");
-					#endif
-				
-				if ( !launcherService.waitForFinished() )
-					qDebug() << "Error while toggling dock icon. LauncherService failed.";
-				else
-					qDebug() << "Toggled dock icon: " << ui_account.showInDockCheck->isChecked();
-			}
-			else
-				qDebug() << "Error while toggling dock icon. Couldn't open plist for writing.";
-        }
-		else
-			qDebug() << "Error while toggling dock icon. Couldn't open plist for reading.";
-	}
+void
+SettingsDialog::clearUserIPodAssociations()
+{
+    // useful no?
+    #define LOG_IF_FAIL( b, x ) bool b = x; if (!b) LOGL( 3, "Failed" #x )
+
+    MediaDeviceSettings().remove( "" );
+    ui_mediadevices.deviceWidget->clear();
+    ui_mediadevices.clearUserAssociations->setEnabled( false );
+
+    // On Windows QFile::remove() may always fail due to file locking.
+    // XP users can uninstall to delete the cache, but Vista users are screwed.
+    // Indeed, it is safe to delete it when iTunes is running, Twiddly handles
+    // it robustly and even shows an error message.
+    LOG_IF_FAIL( b, QFile::remove( Moose::savePath( "iTunesPlays.db" ) ) );
+
+    if (b) LastMessageBox::information(
+                tr("Additional Action Required"),
+                tr("You must restart iTunes before you next try to scrobble your iPod.") );
+}
 
-	bool 
-	SettingsDialog::isDockIconVisible()
-	{
-		// Application itself is in .app/Content/MacOS/, info.plist in .app/Content -> ../info.plist
-		#ifdef QT_NO_DEBUG
-			QString infoPlistFile = "../info.plist";
-		#else
-		// It's only possible to test this function in debug mode on a working final release - located usually in /Applications
-		// This means that you can't hide the icon of the debug version itself in debug mode.
-        // NOTE: There has to be a working release version of the application in the path above! Otherwise this option is invisible...
-			QString infoPlistFile = "/Applications/Last.fm.app/Contents/info.plist";
-		#endif
-		
-		QFile file( infoPlistFile );
-        
-		// Read & WRITE (to check if we have permissions to modify the plist)
-		if ( file.open( QIODevice::ReadWrite ) )
-		{
-			QTextStream fileStream( &file );
-			fileStream.setCodec( "UTF-8" );
-			
-			QString fileContent = fileStream.readAll();
-			
-			file.close();
-			
-			if ( fileContent.indexOf( "\t<key>LSUIElement</key>\n\t<string>1</string>\n" ) == -1 )
-				return true;
-			else
-				return false;
-		}
-		else
-		{	 
-			qDebug() << "Dock icon toggling is deactivated becaue user isn't admin.";
-			ui_account.preferencesGroup->hide();
-			return false;
-		}
-	}
-#endif
