@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 - 2007 by                                          *
+ *   Copyright (C) 2005 - 2008 by                                          *
  *      Christian Muehlhaeuser, Last.fm Ltd <chris@last.fm>                *
  *      Erik Jaelevik, Last.fm Ltd <erik@last.fm>                          *
  *      Jono Cole, Last.fm Ltd <jono@last.fm>                              *
@@ -53,14 +53,16 @@ class SettingsDialog : public QDialog
         void configChanged();
         void pageSwitched( int currentRow );
         void clearCache();
-        void removeMediaDevice();
-        void mediaDeviceItemSelected( QTreeWidgetItem* current, QTreeWidgetItem* previous );
         void verifiedAccount( bool verified, bool bootstrap );
 
         void pageSaved( int page );
         void onOkClicked();
 
+        void clearUserIPodAssociations();
+
     private:
+        void loadExtensions();
+
         void populateAccount();
         void populateRadio();
         void populateScrobbling();
@@ -73,11 +75,6 @@ class SettingsDialog : public QDialog
         void saveConnection();
         void saveMediaDevices();
 
-        #ifdef Q_WS_MAC
-            void toggleDockIcon();
-            bool isDockIconVisible();
-        #endif
-
         Ui::SettingsDialog ui;
         Ui::SettingsDialogAccount ui_account;
         Ui::SettingsDialogRadio ui_radio;
@@ -87,7 +84,7 @@ class SettingsDialog : public QDialog
 
         LoginWidget* m_loginWidget;
 
-        QList<ExtensionInterface*> extensions;
+        QList<ExtensionInterface*> m_extensions;
         QSet<int> m_pagesToSave;
 
         QString originalUsername;
@@ -105,6 +102,7 @@ class SettingsDialog : public QDialog
         bool m_reconnect;
         bool m_reAudio;
         bool m_populating;
+        bool m_closeAfterVerification;
 };
 
 #endif
