@@ -19,6 +19,7 @@
  ***************************************************************************/
 
 #include <QTimer>
+#include <QPushButton>
 #include <QDebug>
 #include <QCompleter>
 #include <QPainter>
@@ -49,11 +50,17 @@ TagDialog::TagDialog( const TrackInfo& track, QWidget *parent )
 
     setTrack( track );
 
+    ui.buttonBox->button( QDialogButtonBox::Ok )->setText( tr("Tag") );
+    ui.buttonBox->button( QDialogButtonBox::Ok )->setEnabled( false );
+
     connect( ui.tagTypeBox, SIGNAL( currentIndexChanged( int ) ), SLOT( onTagTypeChanged( int ) ) );
     connect( ui.personalTagsList, SIGNAL( itemActivated( QTreeWidgetItem*, int ) ), SLOT( onTagActivated( QTreeWidgetItem* ) ) );
     connect( ui.publicTagsList, SIGNAL( itemActivated( QTreeWidgetItem*, int ) ), SLOT( onTagActivated( QTreeWidgetItem* ) ) );
     connect( this, SIGNAL( accepted() ), SLOT( onAccepted() ) );
-    
+
+    connect( ui.buttonBox, SIGNAL( accepted() ), SLOT( accept() ) );
+    connect( ui.buttonBox, SIGNAL( rejected() ), SLOT( reject() ) );
+
     //needs to stay textEdited() not textChanged() or the completion breaks the filtering
     connect( ui.tagEdit, SIGNAL( textEdited( QString ) ), SLOT( onTagEditChanged() ) );
 
@@ -243,7 +250,7 @@ TagDialog::onWebServiceResult( Request *request )
             {
                 QString current_text = ui.tagEdit->text().trimmed();
                 m_originalTags = tags->tags();
-                ui.okButton->setEnabled( !current_text.isEmpty() );
+                ui.buttonBox->button( QDialogButtonBox::Ok )->setEnabled( !current_text.isEmpty() );
                 QStringList tag_edit_tags = QStringList() << m_originalTags << current_text;
                 ui.tagEdit->setText( tag_edit_tags.join( ", " ) );
                 break;
@@ -289,7 +296,7 @@ TagDialog::onTagEditChanged()
     l1.sort();
     l2.sort();
 
-    ui.okButton->setEnabled( l1 != l2 );
+    ui.buttonBox->button( QDialogButtonBox::Ok )->setEnabled( l1 != l2 );
     searchAsYouType( ui.tagEdit->text() );
 }
 
