@@ -317,6 +317,17 @@ CUpdateInfoGetter::PopulateComponent(
     info.SetDownloadURL ( appNode.firstChildElement("Url").text() );
     info.SetVersion     ( appAttributes.namedItem( "version" ).nodeValue() );
     info.SetInstallArgs ( appNode.firstChildElement("Args").text()  );
+
+    if( appAttributes.contains( "majorUpgrade" )) {
+        info.SetMajorUpgrade( appAttributes.namedItem( "majorUpgrade" ).nodeValue()
+                              == "true" );
+    }
+
+    if( !appNode.firstChildElement("Description").isNull())
+        info.SetDescription( appNode.firstChildElement("Description").text());
+
+    if( !appNode.firstChildElement("Image").isNull())
+        info.SetImage( QUrl( appNode.firstChildElement("Image").text()));
 }
 
 /******************************************************************************
